@@ -1,6 +1,7 @@
 from resource import Resource
-from connection import Connection
+from account import Account
 from database import Database
 from document import Document
+from design import Design
 from attachment import Attachment
-from view import View
+from index import Index
